``eradiate._factory``
=====================

.. automodule:: eradiate._factory
   :no-autosummary:

List of ``Factory`` instances
-----------------------------
.. py:currentmodule:: eradiate

.. toctree::
   :hidden:
   :maxdepth: 1
   :glob:

   generated/factory/*

* :data:`radprops.rad_profile_factory`
* :data:`scenes.atmosphere.atmosphere_factory`
* :data:`scenes.atmosphere.particle_distribution_factory`
* :data:`scenes.biosphere.biosphere_factory`
* :data:`scenes.illumination.illumination_factory`
* :data:`scenes.integrators.integrator_factory`
* :data:`scenes.measure.measure_factory`
* :data:`scenes.phase.phase_function_factory`
* :data:`scenes.spectra.spectrum_factory`
* :data:`scenes.surface.surface_factory`

Classes
-------

.. py:currentmodule:: eradiate._factory

.. autoclass:: Factory
   :members:
   :no-autosummary:
